@@ -26,7 +26,6 @@ import (
 	"io"
 	"net/http"
 	"os"
-	"os/exec"
 	"path/filepath"
 	"regexp"
 	"strings"
@@ -39,7 +38,7 @@ import (
 	"github.com/symfony-cli/symfony-cli/book"
 	"github.com/symfony-cli/symfony-cli/git"
 	"github.com/symfony-cli/symfony-cli/local/php"
-	"github.com/symfony-cli/symfony-cli/local/platformsh"
+	"github.com/symfony-cli/symfony-cli/local/upsun"
 	"github.com/symfony-cli/symfony-cli/util"
 	"github.com/symfony-cli/terminal"
 )
@@ -168,10 +167,8 @@ var localNewCmd = &console.Command{
 		}
 
 		if !c.Bool("no-git") {
-			if _, err := exec.LookPath("git"); err == nil {
-				if err := initProjectGit(c, dir); err != nil {
-					return err
-				}
+			if err := initProjectGit(c, dir); err != nil {
+				return err
 			}
 		}
 
@@ -197,16 +194,18 @@ var localNewCmd = &console.Command{
 			if err := runComposer(c, dir, []string{"require", "platformsh"}, c.Bool("debug")); err != nil {
 				return err
 			}
-			buf, err := git.AddAndCommit(dir, []string{"."}, "Add more packages", c.Bool("debug"))
-			if err != nil {
-				fmt.Print(buf.String())
-				return err
+			if !c.Bool("no-git") {
+				buf, err := git.AddAndCommit(dir, []string{"."}, "Add more packages", c.Bool("debug"))
+				if err != nil {
+					fmt.Print(buf.String())
+					return err
+				}
 			}
-			brand := platformsh.PlatformshBrand
+			product := upsun.Fixed
 			if c.Bool("upsun") {
-				brand = platformsh.UpsunBrand
+				product = upsun.Flex
 			}
-			if err := initCloud(c, brand, minorPHPVersion, dir); err != nil {
+			if err := initCloud(c, product, minorPHPVersion, dir); err != nil {
 				return err
 			}
 		}
@@ -235,8 +234,8 @@ func isEmpty(dir string) (bool, error) {
 	return false, err
 }
 
-func initCloud(c *console.Context, brand platformsh.CloudBrand, minorPHPVersion, dir string) error {
-	terminal.Printfln("* Adding %s configuration", brand)
+func initCloud(c *console.Context, product upsun.CloudProduct, minorPHPVersion, dir string) error {
+	terminal.Printfln("* Adding %s configuration", product)
 
 	cloudServices, err := parseCloudServices(dir, c.StringSlice("service"))
 	if err != nil {
@@ -244,12 +243,15 @@ func initCloud(c *console.Context, brand platformsh.CloudBrand, minorPHPVersion,
 	}
 
 	// FIXME: display or hide output based on debug flag
-	_, err = createRequiredFilesProject(brand, dir, "app", "", minorPHPVersion, cloudServices, c.Bool("dump"), c.Bool("force"))
+	_, err = createRequiredFilesProject(product, dir, "app", "", minorPHPVersion, cloudServices, c.Bool("dump"), c.Bool("force"))
 	if err != nil {
 		return err
 	}
 
-	buf, err := git.AddAndCommit(dir, []string{"."}, fmt.Sprintf("Add %s configuration", brand), c.Bool("debug"))
+	if !c.Bool("no-git") {
+		return nil
+	}
+	buf, err := git.AddAndCommit(dir, []string{"."}, fmt.Sprintf("Add %s configuration", product), c.Bool("debug"))
 	if err != nil {
 		fmt.Print(buf.String())
 	}
@@ -278,9 +280,9 @@ func parseCLIServices(services []string) ([]*CloudService, error) {
 		parts := strings.Split(config, ":")
 		if len(parts) == 1 {
 			// service == name
-			service = &CloudService{Name: parts[0], Type: parts[0], Version: platformsh.ServiceLastVersion(parts[1])}
+			service = &CloudService{Name: parts[0], Type: parts[0], Version: upsun.ServiceLastVersion(parts[1])}
 		} else if len(parts) == 2 {
-			service = &CloudService{Name: parts[0], Type: parts[1], Version: platformsh.ServiceLastVersion(parts[1])}
+			service = &CloudService{Name: parts[0], Type: parts[1], Version: upsun.ServiceLastVersion(parts[1])}
 		} else if len(parts) == 3 {
 			service = &CloudService{Name: parts[0], Type: parts[1], Version: parts[2]}
 		} else {
@@ -331,7 +333,7 @@ func parseDockerComposeServices(dir string) []*CloudService {
 				s.Name = service.Name
 				parts := strings.Split(service.Image, ":")
 				s.Version = regexp.MustCompile(`\d+(\.\d+)?`).FindString(parts[len(parts)-1])
-				serviceLastVersion := platformsh.ServiceLastVersion(s.Type)
+				serviceLastVersion := upsun.ServiceLastVersion(s.Type)
 				if s.Version == "" {
 					s.Version = serviceLastVersion
 				} else if s.Version > serviceLastVersion {
