@@ -36,7 +36,6 @@ import (
 
 	compose "github.com/compose-spec/compose-go/cli"
 	composeConsts "github.com/compose-spec/compose-go/consts"
-	"github.com/docker/docker/api/types"
 	"github.com/docker/docker/api/types/container"
 	docker "github.com/docker/docker/client"
 	"github.com/symfony-cli/terminal"
@@ -53,7 +52,7 @@ func ComputeDockerUserAgent(appName, appVersion string) {
 	dockerUserAgent = fmt.Sprintf("Docker-Client/%s %s/%s", dockerClientVersion, appName, appVersion)
 }
 
-type sortedPorts []types.Port
+type sortedPorts []container.Port
 
 func (ps sortedPorts) Len() int           { return len(ps) }
 func (ps sortedPorts) Swap(i, j int)      { ps[i], ps[j] = ps[j], ps[i] }
@@ -148,7 +147,7 @@ func (l *Local) RelationshipsFromDocker() Relationships {
 	return relationships
 }
 
-func (l *Local) dockerServiceToRelationship(client *docker.Client, container types.Container) map[string]map[string]interface{} {
+func (l *Local) dockerServiceToRelationship(client *docker.Client, container container.Summary) map[string]map[string]interface{} {
 	if l.Debug {
 		fmt.Fprintf(os.Stderr, `found Docker container "%s" for project "%s" (image "%s")`+"\n", container.Labels["com.docker.compose.service"], container.Labels["com.docker.compose.project"], container.Image)
 	}
@@ -204,277 +203,281 @@ func (l *Local) dockerServiceToRelationship(client *docker.Client, container typ
 		}
 	}
 
+	if len(exposedPorts) < 1 {
+		return nil
+	}
+
 	sort.Sort(exposedPorts)
-	for _, p := range exposedPorts {
-		rels := make(map[string]map[string]interface{})
-		if p.PrivatePort == 1025 {
-			// recommended image: sj26/mailcatcher or axllent/mailpit (default now)
-			for _, pw := range exposedPorts {
-				if pw.PrivatePort == 1080 || pw.PrivatePort == 8025 {
-					rels["-web"] = map[string]interface{}{
-						"host":   host,
-						"ip":     host,
-						"port":   formatDockerPort(pw.PublicPort),
-						"rel":    "mailer",
-						"scheme": "http",
-					}
-					rels[""] = map[string]interface{}{
-						"host":   host,
-						"ip":     host,
-						"port":   formatDockerPort(p.PublicPort),
-						"rel":    "mailer",
-						"scheme": "smtp",
-					}
-					return rels
-				}
-			}
-		} else if p.PrivatePort == 25 {
-			// recommended image: djfarrelly/maildev
-			for _, pw := range exposedPorts {
-				if pw.PrivatePort == 80 {
-					rels["-web"] = map[string]interface{}{
-						"host":   host,
-						"ip":     host,
-						"port":   formatDockerPort(pw.PublicPort),
-						"rel":    "mailer",
-						"scheme": "http",
-					}
-					rels[""] = map[string]interface{}{
-						"host":   host,
-						"ip":     host,
-						"port":   formatDockerPort(p.PublicPort),
-						"rel":    "mailer",
-						"scheme": "smtp",
-					}
-					return rels
-				}
-			}
-		} else if p.PrivatePort == 8707 || p.PrivatePort == 8307 {
-			// Blackfire
-			rels[""] = map[string]interface{}{
-				"host":   host,
-				"ip":     host,
-				"port":   formatDockerPort(p.PublicPort),
-				"rel":    "blackfire",
-				"scheme": "tcp",
-			}
-			return rels
-		} else if p.PrivatePort == 3306 {
-			username := ""
-			password := ""
-			path := ""
-			version := ""
-			// MARIADB is used by bitnami/mariadb
-			for _, prefix := range []string{"MYSQL", "MARIADB"} {
-				for _, env := range c.Config.Env {
-					if strings.HasPrefix(env, prefix+"_ROOT_PASSWORD") && password == "" {
-						// *_PASSWORD has precedence over *_ROOT_PASSWORD
-						password = getEnvValue(env, prefix+"_ROOT_PASSWORD")
-						username = "root"
-					} else if strings.HasPrefix(env, prefix+"_USER") {
-						username = getEnvValue(env, prefix+"_USER")
-					} else if strings.HasPrefix(env, prefix+"_PASSWORD") {
-						password = getEnvValue(env, prefix+"_PASSWORD")
-					} else if strings.HasPrefix(env, prefix+"_DATABASE") {
-						path = getEnvValue(env, prefix+"_DATABASE")
-					} else if strings.HasPrefix(env, prefix+"_VERSION") {
-						version = getEnvValue(env, prefix+"_VERSION")
-					}
-				}
-			}
-			if path == "" {
-				path = username
-			}
-			rels[""] = map[string]interface{}{
-				"host":     host,
-				"ip":       host,
-				"username": username,
-				"password": password,
-				"path":     path,
-				"version":  version,
-				"port":     formatDockerPort(p.PublicPort),
-				"query": map[string]bool{
-					"is_master": true,
-				},
-				"rel":    "mysql",
-				"scheme": "mysql",
-			}
-			return rels
-		} else if p.PrivatePort == 5432 {
-			username := ""
-			password := ""
-			path := ""
-			version := ""
-			for _, env := range c.Config.Env {
-				if strings.HasPrefix(env, "POSTGRES_USER") {
-					username = getEnvValue(env, "POSTGRES_USER")
-				} else if strings.HasPrefix(env, "POSTGRES_PASSWORD") {
-					password = getEnvValue(env, "POSTGRES_PASSWORD")
-				} else if strings.HasPrefix(env, "POSTGRES_DB") {
-					path = getEnvValue(env, "POSTGRES_DB")
-				} else if strings.HasPrefix(env, "PG_VERSION") {
-					version = getEnvValue(env, "PG_VERSION")
-				}
-			}
-			if path == "" {
-				path = username
-			}
-			rels[""] = map[string]interface{}{
-				"host":     host,
-				"ip":       host,
-				"username": username,
-				"password": password,
-				"path":     path,
-				"version":  version,
-				"port":     formatDockerPort(p.PublicPort),
-				"query": map[string]bool{
-					"is_master": true,
-				},
-				"rel":    "pgsql",
-				"scheme": "pgsql",
-			}
-			return rels
-		} else if p.PrivatePort == 6379 {
-			rels[""] = map[string]interface{}{
-				"host":   host,
-				"ip":     host,
-				"port":   formatDockerPort(p.PublicPort),
-				"rel":    "redis",
-				"scheme": "redis",
-			}
-			return rels
-		} else if p.PrivatePort == 11211 {
-			rels[""] = map[string]interface{}{
-				"host":   host,
-				"ip":     host,
-				"port":   formatDockerPort(p.PublicPort),
-				"rel":    "memcached",
-				"scheme": "memcached",
-			}
-			return rels
-		} else if p.PrivatePort == 5672 {
-			username := "guest"
-			password := "guest"
-			for _, env := range c.Config.Env {
-				// that's our local convention
-				if strings.HasPrefix(env, "RABBITMQ_DEFAULT_USER") {
-					username = getEnvValue(env, "RABBITMQ_DEFAULT_USER")
-				} else if strings.HasPrefix(env, "RABBITMQ_DEFAULT_PASS") {
-					password = getEnvValue(env, "RABBITMQ_DEFAULT_PASS")
-				}
-			}
-			rels[""] = map[string]interface{}{
-				"host":     host,
-				"ip":       host,
-				"port":     formatDockerPort(p.PublicPort),
-				"username": username,
-				"password": password,
-				"rel":      "amqp",
-				"scheme":   "amqp",
-			}
-			// management plugin?
-			for _, pw := range exposedPorts {
-				if pw.PrivatePort == 15672 {
-					rels["-management"] = map[string]interface{}{
-						"host":   host,
-						"ip":     host,
-						"port":   formatDockerPort(pw.PublicPort),
-						"rel":    "amqp",
-						"scheme": "http",
-					}
-					break
-				}
-			}
-			return rels
-		} else if p.PrivatePort == 9200 {
-			rels[""] = map[string]interface{}{
-				"host":   host,
-				"ip":     host,
-				"port":   formatDockerPort(p.PublicPort),
-				"path":   "/",
-				"rel":    "elasticsearch",
-				"scheme": "http",
-			}
-			return rels
-		} else if p.PrivatePort == 5601 {
-			rels[""] = map[string]interface{}{
-				"host":   host,
-				"ip":     host,
-				"port":   formatDockerPort(p.PublicPort),
-				"path":   "/",
-				"rel":    "kibana",
-				"scheme": "http",
-			}
-			return rels
-		} else if p.PrivatePort == 27017 || p.PrivatePort == 27018 || p.PrivatePort == 27019 {
-			username := ""
-			password := ""
-			path := ""
-			for _, env := range c.Config.Env {
-				// that's our local convention
-				if strings.HasPrefix(env, "MONGO_DATABASE") {
-					path = getEnvValue(env, "MONGO_DATABASE")
-				} else if strings.HasPrefix(env, "MONGO_INITDB_DATABASE") {
-					path = getEnvValue(env, "MONGO_INITDB_DATABASE")
-				} else if strings.HasPrefix(env, "MONGO_INITDB_ROOT_USERNAME") {
-					username = getEnvValue(env, "MONGO_INITDB_ROOT_USERNAME")
-				} else if strings.HasPrefix(env, "MONGO_INITDB_ROOT_PASSWORD") {
-					password = getEnvValue(env, "MONGO_INITDB_ROOT_PASSWORD")
-				}
-			}
-			rels[""] = map[string]interface{}{
-				"host":     host,
-				"ip":       host,
-				"username": username,
-				"password": password,
-				"path":     path,
-				"port":     formatDockerPort(p.PublicPort),
-				"rel":      "mongodb",
-				"scheme":   "mongodb",
-			}
-			return rels
-		} else if p.PrivatePort == 9092 {
-			rels[""] = map[string]interface{}{
-				"host":   host,
-				"ip":     host,
-				"port":   formatDockerPort(p.PublicPort),
-				"rel":    "kafka",
-				"scheme": "kafka",
-			}
-			return rels
-		} else if p.PrivatePort == 80 && container.Image == "dunglas/mercure" {
-			rels[""] = map[string]interface{}{
-				"host":   host,
-				"ip":     host,
-				"port":   formatDockerPort(p.PublicPort),
-				"rel":    "mercure",
-				"scheme": "http",
-			}
-			return rels
-		}
+	p := exposedPorts[0]
 
-		if l.Debug {
-			fmt.Fprintln(os.Stderr, "  exposing port")
+	rels := make(map[string]map[string]interface{})
+	if p.PrivatePort == 1025 {
+		// recommended image: sj26/mailcatcher or axllent/mailpit (default now)
+		for _, pw := range exposedPorts {
+			if pw.PrivatePort == 1080 || pw.PrivatePort == 8025 {
+				rels["-web"] = map[string]interface{}{
+					"host":   host,
+					"ip":     host,
+					"port":   formatDockerPort(pw.PublicPort),
+					"rel":    "mailer",
+					"scheme": "http",
+				}
+				rels[""] = map[string]interface{}{
+					"host":   host,
+					"ip":     host,
+					"port":   formatDockerPort(p.PublicPort),
+					"rel":    "mailer",
+					"scheme": "smtp",
+				}
+				return rels
+			}
 		}
-
+	} else if p.PrivatePort == 25 {
+		// recommended image: djfarrelly/maildev
+		for _, pw := range exposedPorts {
+			if pw.PrivatePort == 80 {
+				rels["-web"] = map[string]interface{}{
+					"host":   host,
+					"ip":     host,
+					"port":   formatDockerPort(pw.PublicPort),
+					"rel":    "mailer",
+					"scheme": "http",
+				}
+				rels[""] = map[string]interface{}{
+					"host":   host,
+					"ip":     host,
+					"port":   formatDockerPort(p.PublicPort),
+					"rel":    "mailer",
+					"scheme": "smtp",
+				}
+				return rels
+			}
+		}
+	} else if p.PrivatePort == 8707 || p.PrivatePort == 8307 {
+		// Blackfire
 		rels[""] = map[string]interface{}{
-			"host": host,
-			"ip":   host,
-			"port": formatDockerPort(p.PublicPort),
-			"rel":  "simple",
+			"host":   host,
+			"ip":     host,
+			"port":   formatDockerPort(p.PublicPort),
+			"rel":    "blackfire",
+			"scheme": "tcp",
 		}
-		// Official HTTP(s) ports or well know alternatives
-		if p.PrivatePort == 80 || p.PrivatePort == 8008 || p.PrivatePort == 8080 || p.PrivatePort == 8081 {
-			rels[""]["scheme"] = "http"
-		} else if p.PrivatePort == 443 || p.PrivatePort == 8443 {
-			rels[""]["scheme"] = "https"
-		} else {
-			rels[""]["scheme"] = "tcp"
+		return rels
+	} else if p.PrivatePort == 3306 {
+		username := ""
+		password := ""
+		path := ""
+		version := ""
+		// MARIADB is used by bitnami/mariadb
+		for _, prefix := range []string{"MYSQL", "MARIADB"} {
+			for _, env := range c.Config.Env {
+				if strings.HasPrefix(env, prefix+"_ROOT_PASSWORD") && password == "" {
+					// *_PASSWORD has precedence over *_ROOT_PASSWORD
+					password = getEnvValue(env, prefix+"_ROOT_PASSWORD")
+					username = "root"
+				} else if strings.HasPrefix(env, prefix+"_USER") {
+					username = getEnvValue(env, prefix+"_USER")
+				} else if strings.HasPrefix(env, prefix+"_PASSWORD") {
+					password = getEnvValue(env, prefix+"_PASSWORD")
+				} else if strings.HasPrefix(env, prefix+"_DATABASE") {
+					path = getEnvValue(env, prefix+"_DATABASE")
+				} else if strings.HasPrefix(env, prefix+"_VERSION") {
+					version = getEnvValue(env, prefix+"_VERSION")
+				}
+			}
+		}
+		if path == "" {
+			path = username
+		}
+		rels[""] = map[string]interface{}{
+			"host":     host,
+			"ip":       host,
+			"username": username,
+			"password": password,
+			"path":     path,
+			"version":  version,
+			"port":     formatDockerPort(p.PublicPort),
+			"query": map[string]bool{
+				"is_master": true,
+			},
+			"rel":    "mysql",
+			"scheme": "mysql",
+		}
+		return rels
+	} else if p.PrivatePort == 5432 {
+		username := ""
+		password := ""
+		path := ""
+		version := ""
+		for _, env := range c.Config.Env {
+			if strings.HasPrefix(env, "POSTGRES_USER") {
+				username = getEnvValue(env, "POSTGRES_USER")
+			} else if strings.HasPrefix(env, "POSTGRES_PASSWORD") {
+				password = getEnvValue(env, "POSTGRES_PASSWORD")
+			} else if strings.HasPrefix(env, "POSTGRES_DB") {
+				path = getEnvValue(env, "POSTGRES_DB")
+			} else if strings.HasPrefix(env, "PG_VERSION") {
+				version = getEnvValue(env, "PG_VERSION")
+			}
+		}
+		if path == "" {
+			path = username
+		}
+		rels[""] = map[string]interface{}{
+			"host":     host,
+			"ip":       host,
+			"username": username,
+			"password": password,
+			"path":     path,
+			"version":  version,
+			"port":     formatDockerPort(p.PublicPort),
+			"query": map[string]bool{
+				"is_master": true,
+			},
+			"rel":    "pgsql",
+			"scheme": "pgsql",
+		}
+		return rels
+	} else if p.PrivatePort == 6379 {
+		rels[""] = map[string]interface{}{
+			"host":   host,
+			"ip":     host,
+			"port":   formatDockerPort(p.PublicPort),
+			"rel":    "redis",
+			"scheme": "redis",
+		}
+		return rels
+	} else if p.PrivatePort == 11211 {
+		rels[""] = map[string]interface{}{
+			"host":   host,
+			"ip":     host,
+			"port":   formatDockerPort(p.PublicPort),
+			"rel":    "memcached",
+			"scheme": "memcached",
+		}
+		return rels
+	} else if p.PrivatePort == 5672 {
+		username := "guest"
+		password := "guest"
+		for _, env := range c.Config.Env {
+			// that's our local convention
+			if strings.HasPrefix(env, "RABBITMQ_DEFAULT_USER") {
+				username = getEnvValue(env, "RABBITMQ_DEFAULT_USER")
+			} else if strings.HasPrefix(env, "RABBITMQ_DEFAULT_PASS") {
+				password = getEnvValue(env, "RABBITMQ_DEFAULT_PASS")
+			}
+		}
+		rels[""] = map[string]interface{}{
+			"host":     host,
+			"ip":       host,
+			"port":     formatDockerPort(p.PublicPort),
+			"username": username,
+			"password": password,
+			"rel":      "amqp",
+			"scheme":   "amqp",
+		}
+		// management plugin?
+		for _, pw := range exposedPorts {
+			if pw.PrivatePort == 15672 {
+				rels["-management"] = map[string]interface{}{
+					"host":   host,
+					"ip":     host,
+					"port":   formatDockerPort(pw.PublicPort),
+					"rel":    "amqp",
+					"scheme": "http",
+				}
+				break
+			}
+		}
+		return rels
+	} else if p.PrivatePort == 9200 {
+		rels[""] = map[string]interface{}{
+			"host":   host,
+			"ip":     host,
+			"port":   formatDockerPort(p.PublicPort),
+			"path":   "/",
+			"rel":    "elasticsearch",
+			"scheme": "http",
+		}
+		return rels
+	} else if p.PrivatePort == 5601 {
+		rels[""] = map[string]interface{}{
+			"host":   host,
+			"ip":     host,
+			"port":   formatDockerPort(p.PublicPort),
+			"path":   "/",
+			"rel":    "kibana",
+			"scheme": "http",
+		}
+		return rels
+	} else if p.PrivatePort == 27017 || p.PrivatePort == 27018 || p.PrivatePort == 27019 {
+		username := ""
+		password := ""
+		path := ""
+		for _, env := range c.Config.Env {
+			// that's our local convention
+			if strings.HasPrefix(env, "MONGO_DATABASE") {
+				path = getEnvValue(env, "MONGO_DATABASE")
+			} else if strings.HasPrefix(env, "MONGO_INITDB_DATABASE") {
+				path = getEnvValue(env, "MONGO_INITDB_DATABASE")
+			} else if strings.HasPrefix(env, "MONGO_INITDB_ROOT_USERNAME") {
+				username = getEnvValue(env, "MONGO_INITDB_ROOT_USERNAME")
+			} else if strings.HasPrefix(env, "MONGO_INITDB_ROOT_PASSWORD") {
+				password = getEnvValue(env, "MONGO_INITDB_ROOT_PASSWORD")
+			}
+		}
+		rels[""] = map[string]interface{}{
+			"host":     host,
+			"ip":       host,
+			"username": username,
+			"password": password,
+			"path":     path,
+			"port":     formatDockerPort(p.PublicPort),
+			"rel":      "mongodb",
+			"scheme":   "mongodb",
+		}
+		return rels
+	} else if p.PrivatePort == 9092 {
+		rels[""] = map[string]interface{}{
+			"host":   host,
+			"ip":     host,
+			"port":   formatDockerPort(p.PublicPort),
+			"rel":    "kafka",
+			"scheme": "kafka",
+		}
+		return rels
+	} else if p.PrivatePort == 80 && strings.Contains(container.Image, "dunglas/mercure") {
+		// for podman the image name is docker.io/dunglas/mercure:latest
+		rels[""] = map[string]interface{}{
+			"host":   host,
+			"ip":     host,
+			"port":   formatDockerPort(p.PublicPort),
+			"rel":    "mercure",
+			"scheme": "http",
 		}
 		return rels
 	}
 
-	return nil
+	if l.Debug {
+		fmt.Fprintln(os.Stderr, "  exposing port")
+	}
+
+	rels[""] = map[string]interface{}{
+		"host": host,
+		"ip":   host,
+		"port": formatDockerPort(p.PublicPort),
+		"rel":  "simple",
+	}
+	// Official HTTP(s) ports or well know alternatives
+	switch p.PrivatePort {
+	case 80, 8008, 8080, 8081:
+		rels[""]["scheme"] = "http"
+	case 443, 8443:
+		rels[""]["scheme"] = "https"
+	default:
+		rels[""]["scheme"] = "tcp"
+	}
+	return rels
 }
 
 func formatDockerPort(port uint16) string {
