@@ -30,7 +30,7 @@ import (
 	"strconv"
 
 	"github.com/mitchellh/go-homedir"
-	"github.com/symfony-cli/symfony-cli/local/platformsh"
+	"github.com/symfony-cli/symfony-cli/local/upsun"
 	"github.com/symfony-cli/symfony-cli/util"
 )
 
@@ -44,11 +44,11 @@ type pshtunnel struct {
 }
 
 func (l *Local) relationshipsFromTunnel() Relationships {
-	brand := platformsh.GuessCloudFromDirectory(l.Dir)
-	project, err := platformsh.ProjectFromDir(l.Dir, l.Debug)
+	product := upsun.GuessProductFromDirectory(l.Dir)
+	project, err := upsun.ProjectFromDir(l.Dir, l.Debug)
 	if err != nil {
 		if l.Debug {
-			fmt.Fprintf(os.Stderr, "WARNING: unable to detect %s project: %s\n", brand, err)
+			fmt.Fprintf(os.Stderr, "WARNING: unable to detect %s project: %s\n", product, err)
 		}
 		return nil
 	}
@@ -57,7 +57,7 @@ func (l *Local) relationshipsFromTunnel() Relationships {
 	if err != nil {
 		userHomeDir = ""
 	}
-	tunnelFile := filepath.Join(userHomeDir, brand.CLIConfigPath, "tunnel-info.json")
+	tunnelFile := filepath.Join(userHomeDir, product.CLIConfigPath, "tunnel-info.json")
 	data, err := os.ReadFile(tunnelFile)
 	if err != nil {
 		if l.Debug {
@@ -101,7 +101,7 @@ func (l *Local) relationshipsFromTunnel() Relationships {
 var pathCleaningRegex = regexp.MustCompile(`[^a-zA-Z0-9-\.]+`)
 
 type Tunnel struct {
-	Project *platformsh.Project
+	Project *upsun.Project
 	Worker  string
 	Debug   bool
 }
